antares.apps.user.exceptions package — Antares 0.0.2 documentation

# antares.apps.user.exceptions package

## Submodules

## antares.apps.user.exceptions.role_denied_exception module

Created on Jul 18, 2016

@author: leobelen

exception `antares.apps.user.exceptions.role_denied_exception.` `RoleDeniedException`(value)

  Bases: `Exception`

## antares.apps.user.exceptions.user_exception module

Created on Jul 18, 2016

@author: leobelen

exception `antares.apps.user.exceptions.user_exception.` `UserException`(value)

  Bases: `Exception`

## Module contents